@@ -199,5 +199,7 @@ def manage_cves(values):
         db.truncate_database(values.user, values.password, values.host, values.database)
     if values.cve or values.score or values.date is not -1:
         db.execute_query(values.user, values.password, values.host, values.database, values.cve, values.score, values.date, True)
+    if values.cwe:
+        db.query_for_cwe(values.user, values.password, values.host, values.database, values.cwe, True)
     if not values.input and not values.process and not values.dd and not values.cd and not values.ct and not values.download and not values.process and not values.tr and not values.cve:
         print("Choose an option (check --help)")
